@@ -4,9 +4,10 @@
 Command-line interface
 """
 
+from __future__ import print_function
 import sys
 import argparse
-from firapria.pollution import PollutionFetcher
+from firapria.pollution import get_indices
 
 from colorama import init, Fore
 init(autoreset=True)
@@ -36,14 +37,13 @@ def colorize_indice(i, max_value):
 
 
 def print_pollution():
-    p = PollutionFetcher()
     days = ['Yesterday', 'Today', 'Tomorrow']
 
-    indices = zip(days, p.indices())
+    indices = zip(days, get_indices())
 
-    print "Pollution:"
+    print("Pollution:")
     for day, indice in indices:
-        print "\t%s: %s" % (day, colorize_indice(indice, 100))
+        print("\t%s: %s" % (day, colorize_indice(indice, 100)))
 
 
 def main():
